@@ -680,8 +680,7 @@ class RunnerFitResults:
 
             # Read in the epoch where the best fit was obtained.
             if 'Best short range fit has been obtained in epoch' in line:
-                # Increase by one, because we also read the 0th epoch.
-                self.opt_rmse_epoch = int(data[-1]) + 1
+                self.opt_rmse_epoch = int(data[-1])
 
             # Explicitely handle the special case that the fit did not yield any
             # improvement. This also means that no weights were written.
@@ -734,7 +733,7 @@ class RunnerFitResults:
                   end='')
 
             if epoch == self.opt_rmse_epoch:
-                print(' <-- Best Epoch')
+                print(' <- Best Epoch')
             else:
                 print('')
 
